%define contentdir /var/www
%define mm_ver 1.3.0
%define apache_ver 1.3.29
%define mod_ssl_ver %{version}-%{apache_ver}

Summary: Cryptography support for the Apache Web server.
Name: mod_ssl
Version: 2.8.16
Release: 0.4.1
Group: System Environment/Daemons
Url: http://www.modssl.org/
Source0: ftp://ftp.modssl.org/source/mod_ssl-%{mod_ssl_ver}.tar.bz2
Source1: SSL-Certificate-Creation
Source2: mod_ssl.logrotate
Source3: sxnet.html
Patch0: mod_ssl-2.6.4-tty.patch
Patch1: mod_ssl-2.8.4-sdbm.patch
Patch2: mod_ssl-2.8.4-openssl.patch
Patch3: mod_ssl-2.8.15-flags.patch
License: Apache Software License
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildPrereq: apache-devel = %{apache_ver}, eapi = %{version}, mm-devel
Requires: webserver, make
Prereq: openssl, dev

%description
The mod_ssl module provides strong cryptography for the Apache Web
server via the Secure Sockets Layer (SSL) and Transport Layer Security
(TLS) protocols.

%ifnarch i586 i686 athlon
%package doc
Summary: The manual of mod_ssl package.
Group: Development/Libraries

%description doc
The manual of mod_ssl package.
%endif

%package sxnet
Summary: Strong Extranet module for mod_ssl and apache
Summary(fr): Module d'Extranet Fort pour Apache et mod_ssl
Group: System Environment/Daemons
Prereq: apache = %{apache_ver}, openssl

%description sxnet
The Strong Extranet allows you to use digital certificates to authenticate
users on your web server. Typically, your users enroll in your Strong 
Extranet, under your control, through the Thawte Personal Cert System.  

%description -l fr
L'Extranet Fort vous permet d'utiliser des certificats numeriques pour
authentifier les usagers sur votre serveur web. Typiquement, vos usagers
s'enrolent dans votre Extranet Fort, sous votre controle, a travers le
Thawte Personal Cert System.

%ifnarch i586 i686 athlon
%package sxnet-doc
Summary: The manual of mod_ssl-sxnet package.
Group: Development/Libraries

%description sxnet-doc
The manual of mod_ssl-sxnet package.
%endif

%prep
%setup -q -n %{name}-%{mod_ssl_ver}
%patch0 -p2 -b .tty
%patch1 -p1 -b .sdbm
%patch2 -p1 -b .openssl
%patch3 -p1 -b .flags

pushd pkg.contrib
tar xvf sxnet.tar
popd

%build
CFLAGS="$RPM_OPT_FLAGS -fPIC" ; export CFLAGS

SSL_COMPAT=yes; export SSL_COMPAT
SSL_EXPERIMENTAL=yes ; export SSL_EXPERIMENTAL
# The --force below keeps configure from failing when the httpd binary
# is not present, and changes nothing else.
%configure --with-apxs=%{_sbindir}/apxs --with-mm=SYSTEM --force
make RPM_FLAGS=-I/usr/kerberos/include

cd pkg.contrib/sxnet
%{_sbindir}/apxs -I/usr/include/openssl/ -I/usr/kerberos/include -L/usr/lib -l ssl -l crypto -c mod_sxnet.c

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT`%{_sbindir}/apxs -q LIBEXECDIR`
install -m755 pkg.sslmod/libssl.so $RPM_BUILD_ROOT`%{_sbindir}/apxs -q LIBEXECDIR`
install -m 755 pkg.contrib/sxnet/mod_sxnet.so $RPM_BUILD_ROOT`%{_sbindir}/apxs -q LIBEXECDIR`

# install config information
for suffix in crl crt csr key prm ; do
	mkdir -p $RPM_BUILD_ROOT/`%{_sbindir}/apxs -q SYSCONFDIR`/ssl.${suffix}
	install -m644 pkg.sslcfg/*.${suffix} $RPM_BUILD_ROOT/`%{_sbindir}/apxs -q SYSCONFDIR`/ssl.${suffix}
	rm -f $RPM_BUILD_ROOT/`%{_sbindir}/apxs -q SYSCONFDIR`/ssl.${suffix}/server.*
done
chmod 600 $RPM_BUILD_ROOT/`%{_sbindir}/apxs -q SYSCONFDIR`/ssl.*/*.key

# install log rotation stuff
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
install -m644 $RPM_SOURCE_DIR/mod_ssl.logrotate \
	$RPM_BUILD_ROOT/etc/logrotate.d/mod_ssl

# install docs
mkdir -p $RPM_BUILD_ROOT%{contentdir}/html/manual/mod/mod_ssl/
install -m644 pkg.ssldoc/*.{html,gif,jpg} \
	$RPM_BUILD_ROOT%{contentdir}/html/manual/mod/mod_ssl/

mkdir -p $RPM_BUILD_ROOT%{contentdir}/html/manual/mod/other
install -m 644 $RPM_SOURCE_DIR/sxnet.html $RPM_BUILD_ROOT%{contentdir}/html/manual/mod/other/mod_sxnet.html

# point to the right makefile.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf
ln -s ../../../usr/share/ssl/certs/Makefile $RPM_BUILD_ROOT/etc/httpd/conf

find $RPM_BUILD_ROOT -type f | \
	xargs grep -l "/usr/local/bin/perl5" | \
	xargs perl -pi -e "s|/usr/local/bin/perl5|%{__perl}|g;"
find $RPM_BUILD_ROOT -type f | \
	xargs grep -l "/usr/local/bin/perl" | \
	xargs perl -pi -e "s|/usr/local/bin/perl|%{__perl}|g;"

# create a prototype session cache
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/cache
touch $RPM_BUILD_ROOT%{_localstatedir}/cache/ssl_gcache_data.{dir,pag,sem}

# remove unpackaged files rpm build root
%ifarch i586 i686 athlon
pushd $RPM_BUILD_ROOT
rm -rf .%{contentdir}/html/manual
popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig
umask 077

if [ ! -f %{_sysconfdir}/httpd/conf/ssl.key/server.key ] ; then
%{_bindir}/openssl genrsa -rand /proc/apm:/proc/cpuinfo:/proc/dma:/proc/filesystems:/proc/interrupts:/proc/ioports:/proc/pci:/proc/rtc:/proc/uptime 1024 > %{_sysconfdir}/httpd/conf/ssl.key/server.key 2> /dev/null
fi

if [ ! -f %{_sysconfdir}/httpd/conf/ssl.crt/server.crt ] ; then
cat << EOF | %{_bindir}/openssl req -new -key %{_sysconfdir}/httpd/conf/ssl.key/server.key -x509 -days 365 -out %{_sysconfdir}/httpd/conf/ssl.crt/server.crt 2>/dev/null
--
SomeState
SomeCity
SomeOrganization
SomeOrganizationalUnit
localhost.localdomain
root@localhost.localdomain
EOF
fi

%files
%defattr(-,root,root)
%doc $RPM_SOURCE_DIR/SSL-Certificate-Creation README* LICENSE NEWS CHANGES CREDITS
%{_libdir}/apache/libssl.so
%config %{_sysconfdir}/httpd/conf/Makefile
%attr(0700,root,root) %dir %{_sysconfdir}/httpd/conf/ssl.*
%attr(0600,apache,root) %ghost %{_localstatedir}/cache/ssl_gcache_data.dir
%attr(0600,apache,root) %ghost %{_localstatedir}/cache/ssl_gcache_data.pag
%attr(0600,apache,root) %ghost %{_localstatedir}/cache/ssl_gcache_data.sem
%dir %{_sysconfdir}/httpd
%config %{_sysconfdir}/httpd/conf/ssl.*/*
%{_sysconfdir}/logrotate.d/mod_ssl
  
%files sxnet
%defattr(-,root,root)
%{_libdir}/apache/mod_sxnet.so

%ifnarch i586 i686 athlon
%files doc
%defattr(-,root,root)
%{contentdir}/html/manual/mod/mod_ssl/

%files sxnet-doc
%defattr(-,root,root)
%{contentdir}/html/manual/mod/other/mod_sxnet.html
%endif

%changelog
* Thu Nov  6 2003 Peter Hanecak <hanecak@megaloman.sk> 2.8.16-0.4.1
- recompiled for Doors 4.0 (RedHat 8 like)

* Thu Nov  6 2003 Peter Hanecak <hanecak@megaloman.sk> 2.8.16-1
- updated to 2.8.16

* Fri Oct 17 2003 Peter Hanecak <hanecak@megaloman.sk> 2.8.15-3
- incorporated mod_ssl-2.8.12-httperr.patch from RedHat's
  mod_ssl-2.8.12-3 package

* Wed Oct 15 2003 Peter Hanecak <hanecak@megaloman.sk> 2.8.15-2
- added -I/usr/kerberos/include to CFLAGS

* Tue Jul 29 2003 Peter Hanecak <hanecak@megaloman.sk> 2.8.15-1
- updated to 2.8.15

* Wed Nov 13 2002 Peter Hanecak <hanecak@megaloman.sk> 2.8.12-1
- updated to 2.8.12

* Tue Oct 29 2002 Peter Hanecak <hanecak@megaloman.sk> 2.8.7-7
- forgotten /etc/logrotate.d/mod_ssl included in package

* Fri Jun 28 2002 Peter Hanecak <hanecak@megaloman.sk> 2.8.7-6
- fixed Prereq typo for sxnet package

* Thu Jun 27 2002 Peter Hanecak <hanecak@megaloman.sk> 2.8.7-5
- synchronized with RedHat's mod_ssl-2.8.7-4 package (see below)

* Wed Apr 10 2002 Nalin Dahyabhai <nalin@redhat.com> 2.8.7-3/4
- limit the amount of data used to seed the PRNG (#62346)

* Tue Feb 26 2002 Nalin Dahyabhai <nalin@redhat.com> 2.8.7-2
- rotate engine logs

* Mon Feb 25 2002 Nalin Dahyabhai <nalin@redhat.com> 2.8.7-1
- update to 2.8.7

* Fri Feb 22 2002 Nalin Dahyabhai <nalin@redhat.com> 2.8.6-2
- rebuild

* Fri Feb  1 2002 Nalin Dahyabhai <nalin@redhat.com> 2.8.6-1
- update to 2.8.6

* Wed Jan 23 2002 Nalin Dahyabhai <nalin@redhat.com> 2.8.5-2
- rebuild in new environment

* Sat Oct 27 2001 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.8.5-1.3.22
- merged stuff from RedHat's mod_ssl-2.8.4-9 package (some patches plus
  see below)

* Mon Oct 11 2001 Nalin Dahyabhai <nalin@redhat.com> 2.8.5-1
- update to 2.8.5

* Thu Oct 11 2001 Nalin Dahyabhai <nalin@redhat.com> 2.8.4-10
- update to build against and require 1.3.22

* Tue Jul 24 2001 Nalin Dahyabhai <nalin@redhat.com> 2.8.4-9
- mark files under %%{_sysconfdir} as configuration files
- add dependency on make to ensure that makefiles are usable

* Mon Jul 23 2001 Nalin Dahyabhai <nalin@redhat.com>
- remove a patch

* Thu Jul 19 2001 Nalin Dahyabhai <nalin@redhat.com>
- don't package a default server.anything
- use system mm library
- use --force when configuring so that we don't error out -- the apxs
  script still works

* Wed Jul 18 2001 Nalin Dahyabhai <nalin@redhat.com>
- add a mod_ssl.logrotate configuration file to the package

* Wed Mar  7 2001 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.8.1-1.3.19

* Mon Oct 16 2000 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.7.1-1.3.14
- "requires" changed to "prereq"
- "BuildPreReq mm" changed to "BuildPreReq mm-devel"
- added requires to sxnet package too

* Tue Aug 22 2000 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.6.6-1.3.12
- added %%dir %%{crtsdir} and %%dir %%{keysdir} to %%files
- pkg.contrib/*.sh moved from /usr/local/ssl/mod_ssl to %%{_datadir}/mod_ssl
- documentation moved from %%{contentdir}/html/ssl-doc to
  %%{contentdir}/html/manual/mod/other/mod_ssl and made as separate package
- sxnet documentation moved from %%{contentdir}/html/sxnet/index.html to
  %%{contentdir}/html/manual/mod/other/mod_sxnet.html and made as separate
  package
- %%config(noreplace) used for server.key and server.crt
- do not make doc packages for i586 and i686 architectures

* Tue Jul 18 2000 Peter Hanecak <hanecak@megaloman.sk>
- synchronized with apache-1.3.12-2 (%%{contentdir} is /var/www, ...)
- BuildPreReq apache-devel (because of apxs)
- more info used from apxs

* Thu Jul  6 2000 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.6.5-1.3.12
- %%{_tmppath} used

* Fri May 26 2000 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.6.4-1.3.12
- small spec tweaking

* Thu Mar  9 2000 Michael Tokarev <mjt@tls.msk.ru>
- modified .spec file to simplify installation on non-default http home dir
  (RedHat uses /home/httpd, variants are /var/httpd etc)
- removed implicit dependance on mm library (if used as shared, it
  will be found by rpm); added it to BuildPreReq section
- changed PreReq to BuildPreReq (so that it will not depend on apache-devel)
- added apache-devel to BuildPreReq
- added implicit version of required apache (maybe wrong?)

* Fri Mar  3 2000 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.6.2-1.3.12
- %post changed so it does not include "Include conf/httpd.conf.ssl"
  into http.conf if it is alredy present (even when commented out)

* Wed Mar  1 2000 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.6.1-1.3.12
- requires mm, requires apache-devel for building
- 'apxs' replaced with '/usr/sbin/apxs'
- do not automaticaly restart webserver (%post, %postun)

* Sat Feb 26 2000 Peter Hanecak <hanecak@megaloman.sk>
- update ot 2.6.0-1.3.12
- added URL

* Wed Feb  9 2000 Peter Hanecak <hanecak@megaloman.sk>
- update to 2.5.0-1.3.11
- some little spec changes (vendor, defattr, ...)
- mm library used

* Sat Jun 05 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- moved documentation in html
- rebuilt for the new optimized apache

* Sun May 30 1999 Jean-Michel Dault <jmdault@netrevolution.com>
- updated to 2.3.1
- add fr locale
- added sxnet (Secure ExtraNet) package from Thawte

* Sun May 23 1999 Bernhard Rosenkrnzer <bero@mandrakesoft.com>
- handle RPM_OPT_FLAGS
- add de locale
- don't require openssl-devel
